@@ -1,12 +1,17 @@
 from wiutils.readers import read_project
 from wiutils.extractors import get_scientific_name
 from wiutils.filters import (
-    remove_duplicates, remove_inconsistent_dates, remove_unidentified
+    remove_duplicates,
+    remove_inconsistent_dates,
+    remove_unidentified,
 )
+from wiutils.preprocessors import convert_video_to_images, reduce_image_size
 from wiutils.transformers import (
     compute_deployment_count_summary,
     compute_detection_by_deployment,
     compute_detection_history,
     compute_general_count,
-    compute_hill_numbers
+    compute_hill_numbers,
+    create_dwc_events,
+    create_dwc_records,
 )
